@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2024 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef FILTERBALSAMAILTEST_H
-#define FILTERBALSAMAILTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -21,5 +20,3 @@ private Q_SLOTS:
     void canNotImportDataUnknowPath();
     void canNotImportDataWhenHomeDirSelected();
 };
-
-#endif // FILTERBALSAMAILTEST_H
