@@ -1,12 +1,12 @@
 /*
-  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2024 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "filterplaintest.h"
-#include <MailImporter/FilterPlain>
 #include "filterimportertest.h"
+#include <MailImporter/FilterPlain>
 #include <QTest>
 
 FilterPlainTest::FilterPlainTest(QObject *parent)
@@ -26,7 +26,7 @@ void FilterPlainTest::canNotImportDataEmptyPath()
 {
     MailImporter::FilterPlain filter;
     MailImporter::FilterInfo info;
-    auto *importerTest = new FilterImporterTest(&info);
+    auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(&info);
     filter.importMails(QString());
@@ -38,7 +38,7 @@ void FilterPlainTest::canNotImportDataUnknowPath()
 {
     MailImporter::FilterPlain filter;
     MailImporter::FilterInfo info;
-    auto *importerTest = new FilterImporterTest(&info);
+    auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(&info);
     filter.importMails(QStringLiteral("/foo/kde/bla/toto/"));
@@ -47,3 +47,5 @@ void FilterPlainTest::canNotImportDataUnknowPath()
 }
 
 QTEST_MAIN(FilterPlainTest)
+
+#include "moc_filterplaintest.cpp"
