@@ -41,10 +41,7 @@ FilterLNotes::FilterLNotes()
 }
 
 /** Destructor. */
-FilterLNotes::~FilterLNotes()
-{
-    delete d;
-}
+FilterLNotes::~FilterLNotes() = default;
 
 /**
  * Recursive import of The Bat! maildir.
@@ -119,7 +116,7 @@ void FilterLNotes::ImportLNotes(const QString &file)
                 tempfile->setAutoRemove(false);
                 tempfile->open();
                 // fall through
-                Q_FALLTHROUGH();
+                [[fallthrough]];
             // inside a message state
             case 1:
                 if (ch == 0x0c) {
