@@ -2,7 +2,7 @@
   filterthebat.h  -  TheBat! mail import
 
   SPDX-FileCopyrightText: 2005 Danny Kukawka <danny.kukawka@web.de>
-  SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2024 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -28,9 +28,9 @@ public:
     void importMails(const QString &maildir);
 
 private:
-    void importDirContents(const QString &);
-    void importFiles(const QString &);
-    void processDirectory(const QString &path);
+    MAILIMPORTER_NO_EXPORT void importDirContents(const QString &);
+    MAILIMPORTER_NO_EXPORT void importFiles(const QString &);
+    MAILIMPORTER_NO_EXPORT void processDirectory(const QString &path);
     std::unique_ptr<FilterTheBatPrivate> const d;
 };
 }
