@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2024 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,7 +13,8 @@ namespace MailImporter
 /**
  * Glorified QString[N] for (a) understandability (b) older gcc compatibility.
  */
-template<unsigned int size> class FolderStructureBase
+template<unsigned int size>
+class FolderStructureBase
 {
 public:
     typedef QString NString[size];
@@ -78,4 +79,3 @@ private:
     QString d[size];
 };
 }
-
