@@ -1,12 +1,12 @@
 /*
-  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2024 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "filterbalsamailtest.h"
-#include <MailImporter/FilterBalsa>
 #include "filterimportertest.h"
+#include <MailImporter/FilterBalsa>
 #include <QTest>
 
 FilterBalsaMailTest::FilterBalsaMailTest(QObject *parent)
@@ -26,7 +26,7 @@ void FilterBalsaMailTest::canNotImportDataEmptyPath()
 {
     MailImporter::FilterBalsa filter;
     MailImporter::FilterInfo info;
-    auto *importerTest = new FilterImporterTest(&info);
+    auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(&info);
     filter.importMails(QString());
@@ -38,7 +38,7 @@ void FilterBalsaMailTest::canNotImportDataUnknowPath()
 {
     MailImporter::FilterBalsa filter;
     MailImporter::FilterInfo info;
-    auto *importerTest = new FilterImporterTest(&info);
+    auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(&info);
     filter.importMails(QStringLiteral("/foo/kde/bla/toto/"));
@@ -50,7 +50,7 @@ void FilterBalsaMailTest::canNotImportDataWhenHomeDirSelected()
 {
     MailImporter::FilterBalsa filter;
     MailImporter::FilterInfo info;
-    auto *importerTest = new FilterImporterTest(&info);
+    auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(&info);
     filter.importMails(QDir::homePath());
@@ -59,3 +59,5 @@ void FilterBalsaMailTest::canNotImportDataWhenHomeDirSelected()
 }
 
 QTEST_MAIN(FilterBalsaMailTest)
+
+#include "moc_filterbalsamailtest.cpp"
